==> codelite_2.6.0.4189~dfsg.orig.tar.gz: codelite-2.6.0.4189~dfsg/wxformbuilder/wxformbuilder.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2008 by Eran Ifrah
// file name            : wxformbuilder.h
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#ifndef __wxFormBuilder__
#define __wxFormBuilder__

#include "wxfbitemdlg.h"
#include "plugin.h"
class wxMenuItem;

class wxFormBuilder : public IPlugin
{
	wxEvtHandler *m_topWin;
	wxMenuItem* m_separatorItem;
	wxMenuItem* m_openWithWxFbItem;
	wxMenuItem* m_openWithWxFbSepItem;

public:
	wxFormBuilder(IManager *manager);
	~wxFormBuilder();

protected:
	void OnSettings(wxCommandEvent &e);
	void OnNewDialog(wxCommandEvent &e);
	void OnNewDialogWithButtons(wxCommandEvent &e);
	void OnNewFrame(wxCommandEvent &e);
	void OnNewPanel(wxCommandEvent &e);
	void OpenWithWxFb(wxCommandEvent &e);
	void OnOpenFile(wxCommandEvent &e);

	wxMenu *CreatePopupMenu();
	void DoCreateWxFormBuilderProject(const wxFBItemInfo &data);
	void DoLaunchWxFB(const wxString &file);
	wxString GetWxFBPath();

public:
	//--------------------------------------------
	//Abstract methods
	//--------------------------------------------
	virtual clToolBar *CreateToolBar(wxWindow *parent);
	virtual void CreatePluginMenu(wxMenu *pluginsMenu);
	virtual void HookPopupMenu(wxMenu *menu, MenuType type);
	virtual void UnHookPopupMenu(wxMenu *menu, MenuType type);
	virtual void UnPlug();
};

#endif //wxFormBuilder

==> codelite_6.1.1+dfsg.orig.tar.gz: codelite-6.1.1/wxformbuilder/wxformbuilder.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2008 by Eran Ifrah
// file name            : wxformbuilder.h
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#ifndef __wxFormBuilder__
#define __wxFormBuilder__

#include "wxfbitemdlg.h"
#include "plugin.h"
class wxMenuItem;

class wxFormBuilder : public IPlugin
{
	wxEvtHandler *m_topWin;
	wxMenuItem*   m_separatorItem;
	wxMenuItem*   m_openWithWxFbItem;
	wxMenuItem*   m_openWithWxFbSepItem;
	bool          m_addFileMenu;
	
public:
	wxFormBuilder(IManager *manager);
	~wxFormBuilder();

protected:
	DECLARE_EVENT_TABLE()
	
	void OnSettings(wxCommandEvent &e);
	void OnNewDialog(wxCommandEvent &e);
	void OnNewDialogWithButtons(wxCommandEvent &e);
	void OnNewFrame(wxCommandEvent &e);
	void OnNewPanel(wxCommandEvent &e);
	void OpenWithWxFb(wxCommandEvent &e);
	void OnOpenFile(wxCommandEvent &e);
	void OnWxFBTerminated(wxCommandEvent &e);
	
	wxMenu *CreatePopupMenu();
	void DoCreateWxFormBuilderProject(const wxFBItemInfo &data);
	void DoLaunchWxFB(const wxString &file);
	wxString GetWxFBPath();

public:
	//--------------------------------------------
	//Abstract methods
	//--------------------------------------------
	virtual clToolBar *CreateToolBar(wxWindow *parent);
	virtual void CreatePluginMenu(wxMenu *pluginsMenu);
	virtual void HookPopupMenu(wxMenu *menu, MenuType type);
	virtual void UnPlug();
};

#endif //wxFormBuilder
